#!/usr/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------
# COPYRIGHT (C) 2014-2023 Mitsuo KONDOU.
# This software is released under the not MIT License.
# Permission from the right holder is required for use.
# https://github.com/ClipnGPT
# Thank you for keeping the rules.
# ------------------------------------------------

import json
import os
import time

from selenium.webdriver import Edge
from selenium.webdriver import Chrome
from selenium.webdriver import Firefox
from selenium.webdriver import Safari
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.common.by import By

class _class:

    def __init__(self, ):
        self.version   = "v0"
        self.func_name = "execute_open_web_from_url"
        self.func_ver  = "v0.20230820"
        self.func_auth = "WCHTl5lwkJCIhIVDzAYvEr3JeWl9JYRNz5uKLD5txXacgVSLf0GCFF5aPYtFON1u"
        self.function  = {
            "name": self.func_name,
            "description": \
"""
指定したブラウザでurlのウェブページを表示したり、ブラウザを閉じたりする
""",
            "parameters": {
                "type": "object",
                "properties": {
                    "show_or_hide": {
                        "type": "string",
                        "description": "表示または消去の指定 show,hide (例) show"
                    },
                    "url": {
                        "type": "string",
                        "description": "ウェブページのurl (例) https://openai.com/blog/chatgpt"
                    },
                    "browser": {
                        "type": "string",
                        "description": "ブラウザーの選択 edge,chrome,firefox,safari (例) edge"
                    },
                },
                "required": ["show_or_hide"]
            }
        }

        self.engine_list = []
        res = self.func_reset()

    def __del__(self, ):
        for e in self.engine_list:
            try:
                e.quit()
                e = None
            except:
                pass

    def func_reset(self, ):
        self.__del__()
        return True

    def browser_open(self, url='https://www.google.com/', browser='edge', ):
        try:
            # ブラウザ
            if (browser != None):
                browser = browser.lower()
            if (os.name == 'nt'):
                if   (browser == 'chrome'):
                    engine = Chrome()
                elif (browser == 'firefox'):
                    engine = Firefox()
                elif (browser == 'safari'):
                    engine = Safari()
                else:
                    engine = Edge()
            else:
                if   (browser == 'safari'):
                    engine = Safari()
                elif (browser == 'edge'):
                    engine = Edge()
                elif (browser == 'firefox'):
                    engine = Firefox()
                else:
                    engine = Chrome()
            self.engine_list.append(engine)

            # 最大化
            try:
                engine.maximize_window()
            except Exception as e:
                print(e)

            # WEB ページ開く
            engine.get(url)

            # 全要素取得待機
            engine_wait = WebDriverWait(engine, 10)
            element = engine_wait.until(EC.visibility_of_all_elements_located)

            return True
        except Exception as e:
            print(e)

        return False



    def func_proc(self, json_kwargs=None, ):
        #print(json_kwargs)

        # 引数
        show_or_hide = None
        url          = None
        browser      = None
        if (json_kwargs != None):
            args_dic = json.loads(json_kwargs)
            show_or_hide = args_dic.get('show_or_hide')
            url          = args_dic.get('url')
            browser      = args_dic.get('browser')

        # ブラウザ表示
        if (show_or_hide == 'show'):

            res = self.browser_open(url=url, browser=browser, )
            if (res == True):
                dic = {}
                dic['result'] = "ブラウザ表示しました" 
                json_dump = json.dumps(dic, ensure_ascii=False, )
                #print('  --> ', json_dump)
                return json_dump
            else:
                dic = {}
                dic['error'] = "ブラウザ表示に失敗しました" 
                json_dump = json.dumps(dic, ensure_ascii=False, )
                #print('  --> ', json_dump)
                return json_dump

        # ブラウザ消去
        if (show_or_hide == 'hide'):

            # リセット
            self.func_reset()

            dic = {}
            dic['result'] = "ブラウザ表示を消去しました" 
            json_dump = json.dumps(dic, ensure_ascii=False, )
            #print('  --> ', json_dump)
            return json_dump


if __name__ == '__main__':

    ext = _class()
    print(ext.func_proc('{ ' \
                      + '"show_or_hide" : "show",' \
                      + '"url" : "https://openai.com/blog/chatgpt",' \
                      + '"browser" : "edge"' \
                      + ' }'))
    time.sleep(10.00)

    print(ext.func_proc('{ ' \
                      + '"show_or_hide" : "hide"' \
                      + ' }'))
    time.sleep(2.00)

